class tomcat::tomcatora {
  file { [
    '/usrdata/apps/appserver',
    '/usrdata/apps/sysapps',
    '/usrdata/logs/tomcatlogs',
    '/usrdata/logs/applogs',
    '/usrdata/logs/tomcatlogs/archive',
    '/usrdata/logs/applogs/archive',
    '/usrdata/logs/tomcatlogs/heapdump',
    ]:
    ensure => 'directory',
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}.tar.gz":
    ensure       => present,
    extract      => true,
    extract_path => '/usrdata/apps/appserver/',
    source       => $tomcat::params::tomcatdownloadpath,
    user         => jersey,
    group        => servicesusrgroup,
    creates      => "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}",
  }

  archive { '/usrdata/zipfiles/zipfiles.zip':
    ensure       => present,
    extract      => true,
    extract_path => '/usrdata/zipfiles',
    source       => 'http://10.140.224.220:8080/repository/snwdevops/apache/tomcat/dependencies/zipfiles/1/zipfiles-1.zip',
    creates      => '/usrdata/zipfiles/',
  }

  file { "/usrdata/apps/java/${tomcat::jdkversion}/jre/lib/security/cacerts":
    ensure => file,
    owner  => 'jersey',
    group  => 'servicesusrgroup',
    source => '/usrdata/zipfiles/cacerts',
  }

  file { '/etc/systemd/system/tomcat.service':
    ensure => file,
    owner  => 'jersey',
    mode   => '0755',
    group  => 'servicesusrgroup',
    source => '/usrdata/zipfiles/tomcat.service',
  }

  file { '/usrdata/logs':
    ensure => directory,
    owner  => 'jersey',
    group  => 'servicesusrgroup',
  }

  file { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/lib/":
    ensure  => directory,
    owner   => 'jersey',
    group   => 'servicesusrgroup',
    recurse => true,
  }

  file { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/bin/":
    ensure  => directory,
    owner   => 'jersey',
    group   => 'servicesusrgroup',
    recurse => true,
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/lib/log4j.properties-1":
    ensure  => present,
    user    => jersey,
    extract => false,
    group   => servicesusrgroup,
    source  => $tomcat::params::log4jpropertiesdownloadpath,
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/lib/log4j-${tomcat::log4jversion}.jar":
    ensure  => present,
    user    => jersey,
    extract => false,
    group   => servicesusrgroup,
    source  => $tomcat::params::log4jdownloadpath,
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/lib/apache-log4j-extras-${tomcat::log4jextraversion}.jar"
  :
    ensure  => present,
    user    => jersey,
    extract => false,
    group   => servicesusrgroup,
    source  => $tomcat::params::log4jextradownloadpath,
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/lib/tomcat-juli-adapters.jar":
    ensure  => present,
    user    => jersey,
    extract => false,
    group   => servicesusrgroup,
    source  => $tomcat::params::juliadapterdownloadpath,
  }

  archive { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/bin/tomcat-juli.jar":
    ensure  => present,
    user    => jersey,
    extract => false,
    group   => servicesusrgroup,
    source  => $tomcat::params::tomcatjulidownloadpath,
  }

  file { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/conf/logging.properties": ensure => absent, }

  exec { 'yum remove epel-release-6-8.noarch ': command => 'yum remove epel-release-6-8.noarch  -y', }

  exec { 'yum groupinstall Development Tools':
    command => '/usr/bin/yum -y --disableexcludes=all groupinstall "Development Tools"',
    unless  => '/usr/bin/yum grouplist "Development Tools" | /bin/grep "^Installed"',
    timeout => 600,
  }

  archive { "/tmp/apr-${tomcat::aprversion}.tar.gz":
    ensure       => present,
    extract      => true,
    extract_path => '/tmp',
    source       => $tomcat::params::aprdownloadpath,
    creates      => "/tmp/apr-${tomcat::aprversion}",
  }

  package { 'apr':
    ensure   => installed,
    provider => rpm,
    source   => "/tmp/apr-${tomcat::aprversion}",
  }

  archive { "/tmp/apr-${tomcat::aprutilversion}.tar.gz":
    ensure       => present,
    extract      => true,
    extract_path => '/tmp',
    source       => $tomcat::params::aprutildownloadpath,
    creates      => "/tmp/apr-${tomcat::aprutilversion}",
  }

  package { 'apr-util':
    ensure   => installed,
    provider => rpm,
    source   => "/tmp/apr-${tomcat::aprutilversion}",
  }

  exec { 'installing libapr': command => 'yum install apr-devel.x86_64 -y', }

  exec { 'installing ssldevel': command => 'yum install openssl-devel.x86_64 -y', }

  file { '/etc/profile.d/settomcatparam.sh':
    ensure => file,
    before => File_line['/etc/profile.d/settomcatparam.sh'],
  }

  file_line { '/etc/profile.d/settomcatparam.sh':
    path => '/etc/profile.d/settomcatparam.sh',
    line => 'export LD_LIBRARY_PATH=/usrdata/apps/sysapps/apr/lib:/usrdata/apps/sysapps/apr-util/lib:/usrdata/apps/sysapps/tomcat-native/lib:$LD_LIBRARY_PATH',
  }

  file { "/usrdata/apps/appserver/apache-tomcat-${tomcat::tomcatversion}/logs/":
    ensure => present,
    owner  => 'jersey',
    group  => 'servicesusrgroup',
  }

  exec { 'flush firewall': command => '/usr/sbin/iptables -F', }

  exec { 'add service link ': command => 'systemctl enable  tomcat.service', }
}